@@ -64,21 +64,12 @@
 #include <QFile>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
+#include <QThreadStorage>
 #include <QUrlQuery>
 
 using namespace Attica;
 
-QDebug operator<<(QDebug s, const Attica::Provider &prov)
-{
-    if (prov.isValid()) {
-        s.nospace() << "Provider(" << prov.name() << ':' << prov.baseUrl() << ')';
-    } else {
-        s.nospace() << "Provider(Invalid)";
-    }
-    return s.space();
-}
-
-class Provider::Private : public QSharedData
+class Q_DECL_HIDDEN Provider::Private : public QSharedData
 {
 public:
     QUrl m_baseUrl;
@@ -1134,8 +1125,18 @@ ListJob<Category> *Provider::requestCategories()
         return nullptr;
     }
 
-    QUrl url = createUrl(QLatin1String("content/categories"));
-    ListJob<Category> *job = new ListJob<Category>(d->m_internals, createRequest(url));
+    const QUrl url = createUrl(QLatin1String("content/categories"));
+
+    // Thread-local cache of categories requests. They are fairly slow and block startup
+    static QThreadStorage<QHash<QUrl, ListJob<Category> *>> reqs;
+    ListJob<Category> *job = reqs.localData().value(url);
+    if (!job) {
+        job = new ListJob<Category>(d->m_internals, createRequest(url));
+        QObject::connect(job, &BaseJob::finished, [url] {
+            reqs.localData().remove(url);
+        });
+        reqs.localData().insert(url, job);
+    }
     return job;
 }
 
